@@ -41,7 +41,7 @@ class MockHidapiDevice:
     def write(self, data):
         data = bytes(data)  # ensure data is convertible to bytes
         self.sent.append(Report(data[0], list(data[1:])))
-        return len(data) - 1
+        return len(data)
 
     def get_feature_report(self, report_id, length):
         if self._read:
